==> simses-0.1.2.tar.gz: simses-0.1.2/simses/simulation/storage_system/technology/lithium_ion/degradation_model/calendar_degradation_model/calendar_degradation_model.py <==
from abc import ABC, abstractmethod

from simses.commons.state.technology.lithium_ion_state import LithiumIonState
from simses.simulation.storage_system.technology.lithium_ion.cell_type.cell_type import CellType


class CalendarDegradationModel(ABC):
    """
    Degradation Model for the calendaric aging of the ESS.
    """

    def __init__(self, cell_type: CellType):
        super().__init__()
        self._cell: CellType = cell_type

    @abstractmethod
    def calculate_degradation(self, battery_state: LithiumIonState) -> None:
        """
        update the calendric capacity loss of a battery
        Attention: without considering internal aging variation the capacity loss calculation is conducted on a
        down-scaled single cell and again up-scaled to module or pack assuming that each single cell has the same
        degradation state
        Parameters
        ----------
            battery_state : LithiumIonState
            Current BatteryState of the lithium_ion. Used to determine if the lithium_ion is charging or discharging.

        Returns
        -------

        """
        pass

    @abstractmethod
    def calculate_resistance_increase(self, battery_state: LithiumIonState) -> None:
        """
        update the calendric internal resistance increase of a battery
        Attention: without considering internal aging variation the resistance increase calculation is conducted on a
        down-scaled single cell and again up-scaled to module or pack assuming that each single cell has the same
        degradation state
        Parameters
        ----------
            battery_state : LithiumIonState
            Current BatteryState of the lithium_ion. Used to determine if the lithium_ion is charging or discharging.

        Returns
        -------

        """
        pass

    @abstractmethod
    def get_degradation(self) -> float:
        """
        get the updated calendric capacity loss caused by the current calculation step (differential capacity loss)

        Returns
        -------
        float:
            differential capacity loss of the current step in [Ah]
        """
        pass

    @abstractmethod
    def get_resistance_increase(self) -> float:
        """
        get the updated calendric resistance increase til the current step (differential increase)
        Returns
        -------
        float:
            differential resistance increase til the current step in [p.u.]
        """
        pass

    @abstractmethod
    def reset(self, battery_state: LithiumIonState) -> None:
        """
        resets all values within a calendar degradation model, if battery is replaced
        Parameters
        ----------
            battery_state : LithiumIonState; Current BatteryState of the lithium_ion.

        Returns
        -------
        """
        pass

    @abstractmethod
    def close(self) -> None:
        """
        Closing all resources in calendar degradation model

        Returns
        -------

        """
        pass

==> simses-0.1.7.tar.gz: simses-0.1.7/simses/simulation/storage_system/technology/lithium_ion/degradation_model/calendar_degradation_model/calendar_degradation_model.py <==
from abc import ABC, abstractmethod

from simses.commons.state.technology.lithium_ion_state import LithiumIonState
from simses.simulation.storage_system.technology.lithium_ion.cell_type.cell_type import CellType


class CalendarDegradationModel(ABC):
    """
    Degradation Model for the calendaric aging of the ESS.
    """

    def __init__(self, cell_type: CellType):
        super().__init__()
        self._cell: CellType = cell_type

    @abstractmethod
    def calculate_degradation(self, time: float, battery_state: LithiumIonState) -> None:
        """
        update the calendric capacity loss of a battery
        Attention: without considering internal aging variation the capacity loss calculation is conducted on a
        down-scaled single cell and again up-scaled to module or pack assuming that each single cell has the same
        degradation state
        Parameters
        ----------
            battery_state : LithiumIonState
            Current BatteryState of the lithium_ion. Used to determine if the lithium_ion is charging or discharging.

        Returns
        -------

        """
        pass

    @abstractmethod
    def calculate_resistance_increase(self, time: float, battery_state: LithiumIonState) -> None:
        """
        update the calendric internal resistance increase of a battery
        Attention: without considering internal aging variation the resistance increase calculation is conducted on a
        down-scaled single cell and again up-scaled to module or pack assuming that each single cell has the same
        degradation state
        Parameters
        ----------
            battery_state : LithiumIonState
            Current BatteryState of the lithium_ion. Used to determine if the lithium_ion is charging or discharging.

        Returns
        -------

        """
        pass

    @abstractmethod
    def get_degradation(self) -> float:
        """
        get the updated calendric capacity loss caused by the current calculation step (differential capacity loss)

        Returns
        -------
        float:
            differential capacity loss of the current step in [Ah]
        """
        pass

    @abstractmethod
    def get_resistance_increase(self) -> float:
        """
        get the updated calendric resistance increase til the current step (differential increase)
        Returns
        -------
        float:
            differential resistance increase til the current step in [p.u.]
        """
        pass

    @abstractmethod
    def reset(self, battery_state: LithiumIonState) -> None:
        """
        resets all values within a calendar degradation model, if battery is replaced
        Parameters
        ----------
            battery_state : LithiumIonState; Current BatteryState of the lithium_ion.

        Returns
        -------
        """
        pass

    @abstractmethod
    def close(self) -> None:
        """
        Closing all resources in calendar degradation model

        Returns
        -------

        """
        pass
